.. _technical-label:

=======================
Technical documentation
=======================

.. image:: https://img.shields.io/pypi/v/pytrip.svg
        :target: https://pypi.python.org/pypi/pytrip
.. image:: https://img.shields.io/travis/pytrip/pytrip.svg
        :target: https://travis-ci.org/pytrip/pytrip


.. image:: https://readthedocs.org/projects/pytrip/badge/?version=latest
        :target: https://readthedocs.org/projects/pytrip/?badge=latest
        :alt: Documentation Status

========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - |travis| |appveyor|
    * - package
      - |version| |downloads| |wheel| |supported-versions| |supported-implementations|

.. |docs| image:: https://readthedocs.org/projects/pytrip/badge/?style=flat
    :target: https://readthedocs.org/projects/pytrip
    :alt: Documentation Status

.. |travis| image:: https://travis-ci.org/pytrip/pytrip.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/pytrip/pytrip

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/grzanka/pytrip?branch=master&svg=true
    :alt: Appveyor Build Status
    :target: https://ci.appveyor.com/project/grzanka/pytrip

.. |version| image:: https://img.shields.io/pypi/v/pytrip98.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/pytrip98

.. |downloads| image:: https://img.shields.io/pypi/dm/pytrip98.svg?style=flat
    :alt: PyPI Package monthly downloads
    :target: https://pypi.python.org/pypi/pytrip98

.. |wheel| image:: https://img.shields.io/pypi/wheel/pytrip98.svg?style=flat
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/pytrip98

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/pytrip98.svg?style=flat
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/pytrip98

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/pytrip98.svg?style=flat
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/pytrip98

.. end-badges

Overv.io issue board: https://overv.io/pytrip/pytrip/


Installation
============

Stable version ::

    pip install pytrip98

Latest unstable version, directly GIT repository, using::

    pip install setuptools versioneer
    pip install git+https://github.com/pytrip/pytrip.git

To upgrade, type::

    pip install -U pytrip98

To uninstall, simply use::

    pip uninstall pytrip98

Documentation
=============

https://pytrip.readthedocs.io/

Credits
-------

This package was created with Cookiecutter_ and the `grzanka/cookiecutter-pip-docker-versioneer`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`grzanka/cookiecutter-pip-docker-versioneer`: https://github.com/grzanka/cookiecutter-pip-docker-versioneer
